@@ -37,6 +37,7 @@ along with this program.  If not, see <http://www.gnu.org/licenses/>.
 #include <KWayland/Client/shm_pool.h>
 #include <KWayland/Client/surface.h>
 #include <KWayland/Server/seat_interface.h>
+#include <KWayland/Server/surface_interface.h>
 
 #include <linux/input.h>
 
@@ -62,8 +63,6 @@ private Q_SLOTS:
     void testConfinedPointer();
     void testLockedPointer_data();
     void testLockedPointer();
-    void testBreakConstrainedPointer_data();
-    void testBreakConstrainedPointer();
     void testCloseWindowWithLockedPointer_data();
     void testCloseWindowWithLockedPointer();
 };
@@ -187,41 +186,31 @@ void TestPointerConstraints::testConfinedPointer()
     QCOMPARE(pointerPositionChangedSpy.count(), 1);
     QCOMPARE(KWin::Cursor::pos(), position);
 
-    // let's break the constraint explicitly
-    input()->pointer()->breakPointerConstraints();
-    QCOMPARE(input()->pointer()->isConstrained(), false);
+    // deactivate the client, this should unconfine
+    workspace()->activateClient(nullptr);
     QVERIFY(unconfinedSpy.wait());
+    QCOMPARE(input()->pointer()->isConstrained(), false);
+
+    // reconfine pointer (this time with persistent life time)
     confinedPointer.reset(Test::waylandPointerConstraints()->confinePointer(surface.data(), pointer.data(), nullptr, PointerConstraints::LifeTime::Persistent));
     QSignalSpy confinedSpy2(confinedPointer.data(), &ConfinedPointer::confined);
     QVERIFY(confinedSpy2.isValid());
     QSignalSpy unconfinedSpy2(confinedPointer.data(), &ConfinedPointer::unconfined);
     QVERIFY(unconfinedSpy2.isValid());
-    // should get confined
+
+    // activate it again, this confines again
+    workspace()->activateClient(static_cast<AbstractClient*>(input()->pointer()->window().data()));
     QVERIFY(confinedSpy2.wait());
     QCOMPARE(input()->pointer()->isConstrained(), true);
 
-    // now let's unconfine again, any pointer movement should confine again
-    input()->pointer()->breakPointerConstraints();
-    QCOMPARE(input()->pointer()->isConstrained(), false);
+    // deactivate the client one more time with the persistent life time constraint, this should unconfine
+    workspace()->activateClient(nullptr);
     QVERIFY(unconfinedSpy2.wait());
-    KWin::Cursor::setPos(c->geometry().center());
-    QCOMPARE(KWin::Cursor::pos(), c->geometry().center());
-    QCOMPARE(input()->pointer()->isConstrained(), true);
-    QVERIFY(confinedSpy2.wait());
-
-    // let's use the other break constraint and block
-    input()->pointer()->breakPointerConstraints();
-    input()->pointer()->blockPointerConstraints();
     QCOMPARE(input()->pointer()->isConstrained(), false);
-    KWin::Cursor::setPos(c->geometry().center() + QPoint(1, 1));
-    QCOMPARE(input()->pointer()->isConstrained(), false);
-    QVERIFY(!confinedSpy2.wait());
-
-    // now move outside and back in again, that should confine
-    KWin::Cursor::setPos(c->geometry().bottomRight() + QPoint(1, 1));
-    KWin::Cursor::setPos(c->geometry().center() + QPoint(1, 1));
-    QCOMPARE(input()->pointer()->isConstrained(), true);
+    // activate it again, this confines again
+    workspace()->activateClient(static_cast<AbstractClient*>(input()->pointer()->window().data()));
     QVERIFY(confinedSpy2.wait());
+    QCOMPARE(input()->pointer()->isConstrained(), true);
 
     // create a second window and move it above our constrained window
     QScopedPointer<Surface> surface2(Test::createSurface());
@@ -235,7 +224,7 @@ void TestPointerConstraints::testConfinedPointer()
     QVERIFY(confinedSpy2.wait());
 
     // let's set a region which results in unconfined
-    auto r = Test::waylandCompositor()->createRegion(QRegion(0, 0, 1, 1));
+    auto r = Test::waylandCompositor()->createRegion(QRegion(2, 2, 3, 3));
     confinedPointer->setRegion(r.get());
     surface->commit(Surface::CommitFlag::None);
     QVERIFY(unconfinedSpy2.wait());
@@ -246,6 +235,24 @@ void TestPointerConstraints::testConfinedPointer()
     QVERIFY(confinedSpy2.wait());
     QCOMPARE(input()->pointer()->isConstrained(), true);
 
+    // delete pointer confine
+    confinedPointer.reset(nullptr);
+    Test::flushWaylandConnection();
+
+    QSignalSpy constraintsChangedSpy(input()->pointer()->window()->surface(), &KWayland::Server::SurfaceInterface::pointerConstraintsChanged);
+    QVERIFY(constraintsChangedSpy.isValid());
+    QVERIFY(constraintsChangedSpy.wait());
+
+    // should be unconfined
+    QCOMPARE(input()->pointer()->isConstrained(), false);
+
+    // confine again
+    confinedPointer.reset(Test::waylandPointerConstraints()->confinePointer(surface.data(), pointer.data(), nullptr, PointerConstraints::LifeTime::Persistent));
+    QSignalSpy confinedSpy3(confinedPointer.data(), &ConfinedPointer::confined);
+    QVERIFY(confinedSpy3.isValid());
+    QVERIFY(confinedSpy3.wait());
+    QCOMPARE(input()->pointer()->isConstrained(), true);
+
     // and now unmap
     shellSurface.reset();
     surface.reset();
@@ -294,103 +301,41 @@ void TestPointerConstraints::testLockedPointer()
     KWin::Cursor::setPos(c->geometry().center() + QPoint(1, 1));
     QCOMPARE(KWin::Cursor::pos(), c->geometry().center());
 
-    // now unlock again
-    input()->pointer()->breakPointerConstraints();
+    // deactivate the client, this should unlock
+    workspace()->activateClient(nullptr);
     QCOMPARE(input()->pointer()->isConstrained(), false);
     QVERIFY(unlockedSpy.wait());
 
     // moving cursor should be allowed again
     KWin::Cursor::setPos(c->geometry().center() + QPoint(1, 1));
     QCOMPARE(KWin::Cursor::pos(), c->geometry().center() + QPoint(1, 1));
-}
 
-void TestPointerConstraints::testBreakConstrainedPointer_data()
-{
-    QTest::addColumn<Test::ShellSurfaceType>("type");
+    lockedPointer.reset(Test::waylandPointerConstraints()->lockPointer(surface.data(), pointer.data(), nullptr, PointerConstraints::LifeTime::Persistent));
+    QSignalSpy lockedSpy2(lockedPointer.data(), &LockedPointer::locked);
+    QVERIFY(lockedSpy2.isValid());
 
-    QTest::newRow("wlShell") << Test::ShellSurfaceType::WlShell;
-    QTest::newRow("xdgShellV5") << Test::ShellSurfaceType::XdgShellV5;
-    QTest::newRow("xdgShellV6") << Test::ShellSurfaceType::XdgShellV6;
-}
+    // activate the client again, this should lock again
+    workspace()->activateClient(static_cast<AbstractClient*>(input()->pointer()->window().data()));
+    QVERIFY(lockedSpy2.wait());
+    QCOMPARE(input()->pointer()->isConstrained(), true);
 
-void TestPointerConstraints::testBreakConstrainedPointer()
-{
-    // this test verifies the breaking of Pointer constraints through the keyboard event filter
-    QScopedPointer<Surface> surface(Test::createSurface());
-    QFETCH(Test::ShellSurfaceType, type);
-    QScopedPointer<QObject> shellSurface(Test::createShellSurface(type, surface.data()));
-    QScopedPointer<Pointer> pointer(Test::waylandSeat()->createPointer());
-    QScopedPointer<Keyboard> keyboard(Test::waylandSeat()->createKeyboard());
-    QSignalSpy keyboardEnteredSpy(keyboard.data(), &Keyboard::entered);
-    QVERIFY(keyboardEnteredSpy.isValid());
-    QSignalSpy keyboardLeftSpy(keyboard.data(), &Keyboard::left);
-    QVERIFY(keyboardLeftSpy.isValid());
-    QSignalSpy keyChangedSpy(keyboard.data(), &Keyboard::keyChanged);
-    QVERIFY(keyChangedSpy.isValid());
-    QScopedPointer<LockedPointer> lockedPointer(Test::waylandPointerConstraints()->lockPointer(surface.data(), pointer.data(), nullptr, PointerConstraints::LifeTime::Persistent));
-    QSignalSpy lockedSpy(lockedPointer.data(), &LockedPointer::locked);
-    QVERIFY(lockedSpy.isValid());
-    QSignalSpy unlockedSpy(lockedPointer.data(), &LockedPointer::unlocked);
-    QVERIFY(unlockedSpy.isValid());
+    // try to move the pointer
+    QCOMPARE(input()->pointer()->isConstrained(), true);
+    KWin::Cursor::setPos(c->geometry().center());
+    QCOMPARE(KWin::Cursor::pos(), c->geometry().center() + QPoint(1, 1));
 
-    // now map the window
-    auto c = Test::renderAndWaitForShown(surface.data(), QSize(100, 100), Qt::blue);
-    QVERIFY(c);
-    QVERIFY(!c->geometry().contains(KWin::Cursor::pos()));
-    QVERIFY(keyboardEnteredSpy.wait());
-    // now let's lock
+    // delete pointer lock
+    lockedPointer.reset(nullptr);
+    Test::flushWaylandConnection();
+
+    QSignalSpy constraintsChangedSpy(input()->pointer()->window()->surface(), &KWayland::Server::SurfaceInterface::pointerConstraintsChanged);
+    QVERIFY(constraintsChangedSpy.isValid());
+    QVERIFY(constraintsChangedSpy.wait());
+
+    // moving cursor should be allowed again
     QCOMPARE(input()->pointer()->isConstrained(), false);
     KWin::Cursor::setPos(c->geometry().center());
     QCOMPARE(KWin::Cursor::pos(), c->geometry().center());
-    QCOMPARE(input()->pointer()->isConstrained(), true);
-    QVERIFY(lockedSpy.wait());
-
-    // now try to break
-    quint32 timestamp = 0;
-    kwinApp()->platform()->keyboardKeyPressed(KEY_ESC, timestamp++);
-    QVERIFY(keyChangedSpy.wait());
-    // and just waiting should break constrain
-    QVERIFY(unlockedSpy.wait());
-    QCOMPARE(keyboardLeftSpy.count(), 1);
-    QCOMPARE(input()->pointer()->isConstrained(), false);
-    // and should enter again
-    QTRY_COMPARE(keyboardEnteredSpy.count(), 2);
-    QCOMPARE(waylandServer()->seat()->focusedKeyboardSurface(), c->surface());
-    kwinApp()->platform()->keyboardKeyReleased(KEY_ESC, timestamp++);
-    QVERIFY(!keyChangedSpy.wait());
-    QCOMPARE(keyChangedSpy.count(), 1);
-
-    // now lock again
-    // need to move out and in
-    KWin::Cursor::setPos(c->geometry().bottomRight() + QPoint(1, 1));
-    KWin::Cursor::setPos(c->geometry().center());
-    QCOMPARE(KWin::Cursor::pos(), c->geometry().center());
-    QCOMPARE(input()->pointer()->isConstrained(), true);
-    QVERIFY(lockedSpy.wait());
-
-    // and just do a key press/release on esc
-    kwinApp()->platform()->keyboardKeyPressed(KEY_ESC, timestamp++);
-    kwinApp()->platform()->keyboardKeyReleased(KEY_ESC, timestamp++);
-    QCOMPARE(input()->pointer()->isConstrained(), true);
-    QVERIFY(keyChangedSpy.wait());
-    QCOMPARE(keyChangedSpy.last().at(0).value<quint32>(), quint32(KEY_ESC));
-
-    // and another variant which won't break
-    kwinApp()->platform()->keyboardKeyPressed(KEY_ESC, timestamp++);
-    kwinApp()->platform()->keyboardKeyPressed(KEY_LEFTSHIFT, timestamp++);
-    kwinApp()->platform()->keyboardKeyReleased(KEY_LEFTSHIFT, timestamp++);
-    QCOMPARE(input()->pointer()->isConstrained(), true);
-    QVERIFY(keyChangedSpy.wait());
-    QCOMPARE(keyChangedSpy.last().at(0).value<quint32>(), quint32(KEY_LEFTSHIFT));
-    QVERIFY(!unlockedSpy.wait());
-    kwinApp()->platform()->keyboardKeyReleased(KEY_ESC, timestamp++);
-    QVERIFY(keyChangedSpy.wait());
-    QCOMPARE(keyChangedSpy.last().at(0).value<quint32>(), quint32(KEY_ESC));
-
-    // and now break for real
-    kwinApp()->platform()->keyboardKeyPressed(KEY_ESC, timestamp++);
-    QVERIFY(unlockedSpy.wait());
-    kwinApp()->platform()->keyboardKeyReleased(KEY_ESC, timestamp++);
 }
 
 void TestPointerConstraints::testCloseWindowWithLockedPointer_data()
