@@ -19,7 +19,7 @@ along with this program.  If not, see <http://www.gnu.org/licenses/>.
 *********************************************************************/
 #include "../xkb.h"
 
-#include <QtTest/QtTest>
+#include <QtTest>
 #include <xkbcommon/xkbcommon-keysyms.h>
 
 using namespace KWin;
