@@ -37,7 +37,7 @@ along with this program.  If not, see <http://www.gnu.org/licenses/>.
 #include <QEvent>
 #include <QMouseEvent>
 #include <QTimer>
-#include <QtGui/QVector2D>
+#include <QVector2D>
 #include <QQmlContext>
 #include <QQmlEngine>
 #include <QQuickItem>
@@ -164,7 +164,6 @@ void DesktopGridEffect::prePaintScreen(ScreenPrePaintData& data, int time)
     }
 
     for (auto const &w : effects->stackingOrder()) {
-        m_windowForceBlurRoleState[w] = w->data(WindowForceBlurRole).toBool();
         w->setData(WindowForceBlurRole, QVariant(true));
     }
 
@@ -257,7 +256,7 @@ void DesktopGridEffect::postPaintScreen()
     }
 
     for (auto &w : effects->stackingOrder()) {
-        w->setData(WindowForceBlurRole, m_windowForceBlurRoleState.value(w, false));
+        w->setData(WindowForceBlurRole, QVariant());
     }
 
     effects->postPaintScreen();
